ui

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 4, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Rendered for js/wasm

Index

Constants

This section is empty.

Variables

var (
	Doc *pdf.Document
)

Functions

func CreateBlobURL

func CreateBlobURL(blob any) string

CreateBlobURL crea una URL Blob a partir de un blob.

func GeneratePDF

func GeneratePDF()

GeneratePDF genera el PDF con el título especificado

func GetTitleText

func GetTitleText() string

GetTitleText obtiene el texto del campo de entrada

func Setup

func Setup(doc *pdf.Document)

Setup inicializa y configura toda la interfaz de usuario

func ShowError

func ShowError(message string)

ShowError muestra un mensaje de error en la UI

func ShowPDF

func ShowPDF(dataURL string)

ShowPDF muestra el PDF en el embed

func ShowPDFFromBytes

func ShowPDFFromBytes(pdfBytes []byte)

ShowPDFFromBytes crea un Blob a partir de los bytes del PDF y lo muestra usando Blob API en lugar de base64 para mejor rendimiento

Types

This section is empty.

Jump to