pdf

package module
v0.0.32 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 27, 2026 License: MIT Imports: 4 Imported by: 0

README

TinyPDF

Project Badges

Overview

This library is designed for web rendering with WebAssembly. It is optimized for TinyGo compatibility, with all standard library components that are not compatible with TinyGo being removed or replaced.

The fork of go-pdf https://github.com/jung-kurt/gofpdf

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetPDFBytes

func GetPDFBytes(pdf *fpdf.Fpdf, w io.Writer) error

GetPDFBytes genera el PDF y retorna los bytes IMPORTANTE: Cierra el PDF internamente

Types

type TinyPDF

type TinyPDF struct {
	Fpdf *fpdf.Fpdf
	// contains filtered or unexported fields
}

func New

func New(options ...any) *TinyPDF

func (*TinyPDF) GenerateSamplePDF

func (tp *TinyPDF) GenerateSamplePDF(title string) (*fpdf.Fpdf, error)

GenerateSamplePDF genera un PDF de ejemplo con el título especificado Esta función es independiente del entorno (WASM o backend) IMPORTANTE: Crea una nueva instancia de PDF cada vez

func (*TinyPDF) Log

func (tp *TinyPDF) Log(message ...any)

Log escribe mensajes de log según el entorno En backend usa fmt.Println, en frontend usa console.log

Directories

Path Synopsis
list command
makefont command
Command makefont generates a font definition file.
Command makefont generates a font definition file.

Jump to